pub struct CorkStream<IO> {
pub io: IO,
pub corked: bool,
/* private fields */
}Expand description
This is a wrapper that reads TLS message headers so it knows when to start doing empty reads at the message boundary when “draining” a rustls connection before setting up kTLS for it.
The short explanation is: rustls might have buffered one or more ApplicationData messages (the last one might even be partial) by the time “connect” / “accept” returns.
We not only need to pop messages rustls has already deframed (that’s done in a drain function elsewhere), but also let rustls finish reading and deframing any partial message it may have already buffered.
Because this wrapper is trying very hard not to do any error handling, if it encounters anything that doesn’t look like a TLS header (unknown type, nonsensical size, unexpected EOF), it’ll quite easily fall back to a “passthrough” mode with no internal buffering, letting rustls take care reporting any errors.
Fields
io: IOcorked: boolImplementations
Sourceimpl<IO> CorkStream<IO>
impl<IO> CorkStream<IO>